@@ -7,7 +7,7 @@ OPEN_STREET_MAP_DE = TileLayer(
     name="OpenStreetMap"
 )
 
-OPEN_STREET_MAP_BW = TileLayer(
+OPEN_STREET_MAP_BW = TileLayer(  # No longer maintained
     url='https://{s}.tiles.wmflabs.org/bw-mapnik/{z}/{x}/{y}.png',
     max_zoom=19,
     name="OpenStreetMap BW"
