@@ -823,7 +823,7 @@ class RDYFile:
                     info = dict(pd.read_sql_query("SELECT * from measurment_information_table", db_con))
                 except (DatabaseError, PandasDatabaseError) as e:
                     logger.error(
-                        "DatabaseError occurred when accessing measurement_information_table, file: %s" % self.filename)
+                        "(%s) DatabaseError occurred when accessing measurement_information_table" % self.filename)
                     logger.error(e)
                     info = {}
 
@@ -833,14 +833,14 @@ class RDYFile:
                     self.sensors.append(Sensor(**dict(row)))
             except (DatabaseError, PandasDatabaseError) as e:
                 logger.error(
-                    "DatabaseError occurred when accessing sensor_descriptions_table, file: %s" % self.filename)
+                    "(%s) DatabaseError occurred when accessing sensor_descriptions_table" % self.filename)
                 logger.error(e)
 
             try:
                 device_df = pd.read_sql_query("SELECT * from device_information_table", db_con)
                 self.device = Device(**dict(device_df))
             except (DatabaseError, PandasDatabaseError) as e:
-                logger.error("DatabaseError occurred when accessing device_information_table, file: %s" % self.filename)
+                logger.error("(%s) DatabaseError occurred when accessing device_information_table" % self.filename)
                 logger.error(e)
                 self.device = Device()
 
@@ -911,7 +911,7 @@ class RDYFile:
                                            rdy_format_version=self.rdy_format_version,
                                            **dict(acc_df))
                 except (DatabaseError, PandasDatabaseError) as e:
-                    logger.error("DatabaseError occurred when accessing acc_measurements_table, file: %s" % self.filename)
+                    logger.error("(%s) DatabaseError occurred when accessing acc_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and AccelerationUncalibratedSeries in self._series) or self._series is None:
@@ -920,7 +920,7 @@ class RDYFile:
                     self.measurements[AccelerationUncalibratedSeries] = AccelerationUncalibratedSeries(
                         filename=self.filename, rdy_format_version=self.rdy_format_version, **dict(acc_uncal_df))
                 except (DatabaseError, PandasDatabaseError) as e:
-                    logger.error("DatabaseError occurred when accessing acc_uncal_measurements_table, file: %s" % self.filename)
+                    logger.error("(%s) DatabaseError occurred when accessing acc_uncal_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and LinearAccelerationSeries in self._series) or self._series is None:
@@ -932,7 +932,7 @@ class RDYFile:
                         **dict(lin_acc_df))
                 except (DatabaseError, PandasDatabaseError) as e:
                     logger.error(
-                        "DatabaseError occurred when accessing lin_acc_measurements_table, file: %s" % self.filename)
+                        "(%s) DatabaseError occurred when accessing lin_acc_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and MagnetometerSeries in self._series) or self._series is None:
@@ -942,7 +942,7 @@ class RDYFile:
                                                                                rdy_format_version=self.rdy_format_version,
                                                                                **dict(mag_df))
                 except (DatabaseError, PandasDatabaseError) as e:
-                    logger.error("DatabaseError occurred when accessing mag_measurements_table, file: %s" % self.filename)
+                    logger.error("(%s) DatabaseError occurred when accessing mag_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and MagnetometerUncalibratedSeries in self._series) or self._series is None:
@@ -951,7 +951,7 @@ class RDYFile:
                     self.measurements[MagnetometerUncalibratedSeries] = MagnetometerUncalibratedSeries(
                         filename=self.filename, rdy_format_version=self.rdy_format_version, **dict(mag_uncal_df))
                 except (DatabaseError, PandasDatabaseError) as e:
-                    logger.error("DatabaseError occurred when accessing mag_uncal_measurements_table, file: %s" % self.filename)
+                    logger.error("(%s) DatabaseError occurred when accessing mag_uncal_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and OrientationSeries in self._series) or self._series is None:
@@ -962,7 +962,7 @@ class RDYFile:
                                                                              **dict(orient_df))
                 except (DatabaseError, PandasDatabaseError) as e:
                     logger.error(
-                        "DatabaseError occurred when accessing orient_measurements_table, file: %s" % self.filename)
+                        "(%s) DatabaseError occurred when accessing orient_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and GyroSeries in self._series) or self._series is None:
@@ -972,7 +972,7 @@ class RDYFile:
                                                                rdy_format_version=self.rdy_format_version,
                                                                **dict(gyro_df))
                 except (DatabaseError, PandasDatabaseError) as e:
-                    logger.error("DatabaseError occurred when accessing gyro_measurements_table, file: %s" % self.filename)
+                    logger.error("(%s) DatabaseError occurred when accessing gyro_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and GyroUncalibratedSeries in self._series) or self._series is None:
@@ -982,7 +982,7 @@ class RDYFile:
                         filename=self.filename, rdy_format_version=self.rdy_format_version, **dict(gyro_uncal_df))
                 except (DatabaseError, PandasDatabaseError) as e:
                     logger.error(
-                        "DatabaseError occurred when accessing gyro_uncal_measurements_table, file: %s" % self.filename)
+                        "(%s) DatabaseError occurred when accessing gyro_uncal_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and RotationSeries in self._series) or self._series is None:
@@ -992,7 +992,7 @@ class RDYFile:
                                                                        rdy_format_version=self.rdy_format_version,
                                                                        **dict(rot_df))
                 except (DatabaseError, PandasDatabaseError) as e:
-                    logger.error("DatabaseError occurred when accessing rot_measurements_table, file: %s" % self.filename)
+                    logger.error("(%s) DatabaseError occurred when accessing rot_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and GPSSeries in self._series) or self._series is None:
@@ -1002,7 +1002,7 @@ class RDYFile:
                                                              rdy_format_version=self.rdy_format_version,
                                                              **dict(gps_df))
                 except (DatabaseError, PandasDatabaseError) as e:
-                    logger.error("DatabaseError occurred when accessing gps_measurements_table, file: %s" % self.filename)
+                    logger.error("(%s) DatabaseError occurred when accessing gps_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and GNSSMeasurementSeries in self._series) or self._series is None:
@@ -1011,7 +1011,7 @@ class RDYFile:
                     self.measurements[GNSSMeasurementSeries] = GNSSMeasurementSeries(
                         filename=self.filename, rdy_format_version=self.rdy_format_version, **dict(gnss_df))
                 except (DatabaseError, PandasDatabaseError) as e:
-                    logger.error("DatabaseError occurred when accessing gnss_measurement_table, file: %s" % self.filename)
+                    logger.error("(%s) DatabaseError occurred when accessing gnss_measurement_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and GNSSClockMeasurementSeries in self._series) or self._series is None:
@@ -1020,7 +1020,7 @@ class RDYFile:
                     self.measurements[GNSSClockMeasurementSeries] = GNSSClockMeasurementSeries(
                         filename=self.filename, rdy_format_version=self.rdy_format_version, **dict(gnss_clock_df))
                 except (DatabaseError, PandasDatabaseError) as e:
-                    logger.error("DatabaseError occurred when accessing gnss_clock_measurement_table, file: %s" % self.filename)
+                    logger.error("(%s) DatabaseError occurred when accessing gnss_clock_measurement_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and NMEAMessageSeries in self._series) or self._series is None:
@@ -1029,7 +1029,7 @@ class RDYFile:
                     self.measurements[NMEAMessageSeries] = NMEAMessageSeries(
                         filename=self.filename, rdy_format_version=self.rdy_format_version, **dict(nmea_df))
                 except (DatabaseError, PandasDatabaseError) as e:
-                    logger.error("DatabaseError occurred when accessing nmea_messages_table, file: %s" % self.filename)
+                    logger.error("(%s) DatabaseError occurred when accessing nmea_messages_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and PressureSeries in self._series) or self._series is None:
@@ -1040,7 +1040,7 @@ class RDYFile:
                                                                        **dict(pressure_df))
                 except (DatabaseError, PandasDatabaseError) as e:
                     logger.error(
-                        "DatabaseError occurred when accessing pressure_measurements_table, file: %s" % self.filename)
+                        "(%s) DatabaseError occurred when accessing pressure_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and TemperatureSeries in self._series) or self._series is None:
@@ -1051,7 +1051,7 @@ class RDYFile:
                                                                              **dict(temperature_df))
                 except (DatabaseError, PandasDatabaseError) as e:
                     logger.error(
-                        "DatabaseError occurred when accessing temperature_measurements_table, file: %s" % self.filename)
+                        "(%s) DatabaseError occurred when accessing temperature_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and HumiditySeries in self._series) or self._series is None:
@@ -1062,7 +1062,7 @@ class RDYFile:
                                                                        **dict(humidity_df))
                 except (DatabaseError, PandasDatabaseError) as e:
                     logger.error(
-                        "DatabaseError occurred when accessing humidity_measurements_table, file: %s" % self.filename)
+                        "(%s) DatabaseError occurred when accessing humidity_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and LightSeries in self._series) or self._series is None:
@@ -1072,7 +1072,7 @@ class RDYFile:
                                                                  rdy_format_version=self.rdy_format_version,
                                                                  **dict(light_df))
                 except (DatabaseError, PandasDatabaseError) as e:
-                    logger.error("DatabaseError occurred when accessing light_measurements_table, file: %s" % self.filename)
+                    logger.error("(%s) DatabaseError occurred when accessing light_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and WzSeries in self._series) or self._series is None:
@@ -1082,7 +1082,7 @@ class RDYFile:
                                                            rdy_format_version=self.rdy_format_version,
                                                            **dict(wz_df))
                 except (DatabaseError, PandasDatabaseError) as e:
-                    logger.error("DatabaseError occurred when accessing wz_measurements_table, file: %s" % self.filename)
+                    logger.error("(%s) DatabaseError occurred when accessing wz_measurements_table" % self.filename)
                     logger.error(e)
 
             if (self._series is not None and SubjectiveComfortSeries in self._series) or self._series is None:
@@ -1094,7 +1094,7 @@ class RDYFile:
                         **dict(subjective_comfort_df))
                 except (DatabaseError, PandasDatabaseError) as e:
                     logger.error(
-                        "DatabaseError occurred when accessing subjective_comfort_measurements_table, file: %s" % self.filename)
+                        "(%s) DatabaseError occurred when accessing subjective_comfort_measurements_table" % self.filename)
                     logger.error(e)
 
             db_con.close()
@@ -1104,7 +1104,8 @@ class RDYFile:
 
         if self.cutoff:
             for m in self.measurements.values():
-                m.cutoff(self.timestamp_when_started, self.timestamp_when_stopped)
+                if len(m) > 0:
+                    m.cutoff(self.timestamp_when_started, self.timestamp_when_stopped)
 
     def to_df(self, interpolate: bool = True) -> pd.DataFrame:
         """ Merges the measurement series to a single DataFrame
