@@ -56,6 +56,7 @@ class OSM:
 
         self.overpass_api = overpy.Overpass()
         self.overpass_api_alt = overpy.Overpass(url="https://overpass.kumi.systems/api/interpreter")
+        self.overpass_api_ifs = overpy.Overpass(url="http://134.130.76.80:12345/api/interpreter")
 
         self.lon_sw = lon_sw
         self.lat_sw = lat_sw
@@ -93,7 +94,10 @@ class OSM:
                          for n1, n2 in zip(w.nodes, w.nodes[1:])]
                 self.G.add_weighted_edges_from(edges, weight="d", way_id=w.id)
 
-            self._check_allowed_switch_transits()
+            if len(self.G.nodes) > 0:
+                self._check_allowed_switch_transits()
+            else:
+                logger.warning("Can't check allowed switch transits, because the Graph has no nodes!")
 
         logger.info("Initialized region: %f, %f (SW), %f, %f (NE)" % (self.lon_sw,
                                                                       self.lat_sw,
@@ -149,7 +153,7 @@ class OSM:
                     v2 = [n2_x - sw_x, n2_y - sw_y]
 
                     ang = calc_angle_between(v1, v2)
-                    if ang > math.pi/2:
+                    if ang > math.pi / 2:
                         allowed_transits.append((n1, sw.id, n2))
 
             sw.allowed_transits = allowed_transits
@@ -223,23 +227,42 @@ class OSM:
             logger.warning("Cant download OSM data because of not internet connection")
 
     def query_overpass(self, query: str, attempts: int = 3) -> Result:
-        for a in range(attempts):
+        if internet(host="134.130.76.80", port=12345):  # IFS internal Overpass instance
+            for a in range(attempts):
+                time.sleep(a)
+                try:
+                    logger.info("Trying to query OSM data, %d/%d tries" % (a, attempts))
+                    result = self.overpass_api_ifs.query(query)
+                    logger.info("Successfully queried OSM Data using IFS Overpass instance")
+                    return result
+                except overpy.exception.OverpassTooManyRequests as e:
+                    logger.warning("OverpassTooManyRequest (IFS Overpass instance), retrying".format(e))
+                except overpy.exception.OverpassRuntimeError as e:
+                    logger.warning("OverpassRuntimeError (IFS Overpass instance), retrying".format(e))
+                except overpy.exception.OverpassGatewayTimeout as e:
+                    logger.warning("OverpassTooManyRequest (IFS Overpass instance), retrying".format(e))
+                except overpy.exception.OverpassBadRequest as e:
+                    logger.warning("OverpassTooManyRequest (IFS Overpass instance), retrying".format(e))
+                except socket.timeout as e:
+                    logger.warning("Socket timeout (IFS Overpass instance), retrying".format(e))
+
+        for a in range(attempts):  # Default Overpass instance
             time.sleep(a)
             try:
                 logger.info("Trying to query OSM data, %d/%d tries" % (a, attempts))
                 result = self.overpass_api.query(query)
-                logger.info("Successfully queried OSM Data")
+                logger.info("Successfully queried OSM Data using default Overpass instance")
                 return result
             except overpy.exception.OverpassTooManyRequests as e:
-                logger.warning("OverpassTooManyRequest, retrying".format(e))
+                logger.warning("OverpassTooManyRequest (Default Overpass instance), retrying".format(e))
             except overpy.exception.OverpassRuntimeError as e:
-                logger.warning("OverpassRuntimeError, retrying".format(e))
+                logger.warning("OverpassRuntimeError (Default Overpass instance), retrying".format(e))
             except overpy.exception.OverpassGatewayTimeout as e:
-                logger.warning("OverpassTooManyRequest, retrying".format(e))
+                logger.warning("OverpassTooManyRequest (Default Overpass instance), retrying".format(e))
             except overpy.exception.OverpassBadRequest as e:
-                logger.warning("OverpassTooManyRequest, retrying".format(e))
+                logger.warning("OverpassTooManyRequest (Default Overpass instance), retrying".format(e))
             except socket.timeout as e:
-                logger.warning("Socket timeout, retrying".format(e))
+                logger.warning("Socket timeout (Default Overpass instance), retrying".format(e))
 
         logger.info("Using alternative Overpass API url")
         for a in range(attempts):
@@ -247,18 +270,18 @@ class OSM:
             try:
                 logger.info("Trying to query OSM data, %d/%d tries" % (a, attempts))
                 result = self.overpass_api_alt.query(query)
-                logger.info("Successfully queried OSM Data")
+                logger.info("Successfully queried OSM Data using alternative instance")
                 return result
             except overpy.exception.OverpassTooManyRequests as e:
-                logger.warning("OverpassTooManyRequest, retrying".format(e))
+                logger.warning("OverpassTooManyRequest (Alternative Overpass instance), retrying".format(e))
             except overpy.exception.OverpassRuntimeError as e:
-                logger.warning("OverpassRuntimeError, retrying".format(e))
+                logger.warning("OverpassRuntimeError (Alternative Overpass instance), retrying".format(e))
             except overpy.exception.OverpassGatewayTimeout as e:
-                logger.warning("OverpassTooManyRequest, retrying".format(e))
+                logger.warning("OverpassTooManyRequest (Alternative Overpass instance), retrying".format(e))
             except overpy.exception.OverpassBadRequest as e:
-                logger.warning("OverpassTooManyRequest, retrying".format(e))
+                logger.warning("OverpassTooManyRequest (Alternative Overpass instance), retrying".format(e))
             except socket.timeout as e:
-                logger.warning("Socket timeout, retrying".format(e))
+                logger.warning("Socket timeout (Alternative Overpass instance), retrying".format(e))
         else:
             logger.warning("Could download OSM data via Overpass after %d attempts with query: %s" % (attempts,
                                                                                                       query))
@@ -354,7 +377,7 @@ class OSM:
                     if u_is_switch:
                         u_prev = prev[u]
                         allowed = True if (u_prev, u, v) in self.G.nodes[u]['attributes'].get('allowed_transits',
-                                                                                         []) else False
+                                                                                              []) else False
                     else:
                         allowed = True
 
